/**
 * Copyright 2006 Google Inc.
 * All Rights Reserved.
 *
 * This js file contains the javascript code that is used by
 * ffloadgraph-toolbar.xul and ffloadgraph-colors.xul.
 *
 * This code is part of a Firefox extension.
 *
 * Written by Liz Looney.
 */

/**
 * Called from ffloadgraph-toolbar.xul when a window loads.
 */
function fflg_OnLoad(event) {
  fflg_SendEvent(event.target, "OnLoad");
}

/**
 * Called from ffloadgraph-toolbar.xul when the user chooses the clear button.
 *
 * @param win
 */
function fflg_ClearEvents(win) {
  fflg_SendEvent(win, "ClearEvents");
}

/**
 * Called from ffloadgraph-toolbar.xul when the user chooses the graph button.
 *
 * @param win
 */
function fflg_GraphEvents(win) {
  fflg_SendEvent(win, "GraphEvents");
}

/**
 * Called from ffloadgraph-toolbar.xul when the user changes a recording option.
 *
 * @param win
 */
function fflg_RecordOptionChanged(win) {
  fflg_SendEvent(win, "RecordOptionChanged");
}

/**
 * Called from ffloadgraph-toolbar.xul when the user changes a setting that
 * affects the graph, such as the scale.
 * Also called from fflg_ColorsOnDialogAccept, below.
 *
 * @param win - the graph window
 */
function fflg_GraphOptionChanged(win) {
  fflg_SendEvent(win, "GraphOptionChanged");
}

/**
 * Called from ffloadgraph-toolbar.xul when the user wants to change the colors
 * used on the graph.
 *
 * @param win - the graph window
 */
function fflg_PickColors(win) {
  win.openDialog("chrome://ffloadgraph/content/ffloadgraph-colors.xul",
      "fflgColors",
      "modal,centerscreen,chrome,resizable=yes",
      win);       // window.arguments[0]
}


/**
 * Called from ffloadgraph-colors.xul when the user presses ok in the colors
 * dialog.
 *
 * @param win - the colors dialog
 */
function fflg_ColorsOnDialogAccept(win) {
  var graphWin = win.arguments[0];
  // graphWin is the window that contains the load graph

  // Update the graph.
  fflg_GraphOptionChanged(graphWin);
}

/**
 * Sends an event to the ffloadgraph application.
 *
 * @param subject nsISupports
 * @param data string
 */
function fflg_SendEvent(subject, data) {
  Components.classes["@mozilla.org/observer-service;1"].
      getService(Components.interfaces.nsIObserverService).
      notifyObservers(subject, "fflg_event", data);
}

/**
 * Prints a message to the Javascript console.
 *
 * @param msg string
 */
/* fflg_printToJSConsole is not used
function fflg_printToJSConsole(msg) {
  Components.classes["@mozilla.org/consoleservice;1"].
      getService(Components.interfaces.nsIConsoleService).
      logStringMessage("FFLG: " + msg);
}
*/
